require 'json'
require 'converter'
require 'thermostat'

class JSONThermostat
  attr_reader :temperature, :range, :unit, :unit_m, :update

  def initialize(settings)
    @temperature = JSON.parse(settings)['temperature']
    @unit = JSON.parse(settings)['unit']
    @range = JSON.parse(settings)['range'] / 2
  end

  def update(measurement)
    @temperature_m = JSON.parse(measurement)['temperature']
    @unit_m = JSON.parse(measurement)['unit']
    unit_check

    heat_or_cool
  end

  def heat_or_cool
    thermo = { cooling: false, heating: false }

    if Thermostat.new.airco_temperature(@temperature_m, temperature, range)
      thermo[:cooling] = true
    end
    if Thermostat.new.heating_temperature(@temperature_m, temperature, range)
      thermo[:heating] = true
    end

    JSON.generate(thermo)
  end

  def unit_check 
    if (unit == 'celsius' || unit.to_s.empty?) && unit_m == 'kelvin'
      @temperature_m = Converter.new.ktoc(@temperature_m)
    end

    if (unit == 'celsius' || unit.to_s.empty?) && unit_m == 'fahrenheit'
      @temperature_m = Converter.new.ftoc(@temperature_m)
    end

    if unit == 'kelvin' && (unit_m == 'celsius' || unit_m.to_s.empty?)
      @temperature_m = Converter.new.ctok(@temperature_m)
    end

    if unit == 'kelvin' && unit_m == 'fahrenheit'
      @temperature_m = Converter.new.ftok(@temperature_m)
    end

    if unit == 'fahrenheit' && unit_m == 'kelvin'
      @temperature_m = Converter.new.ktof(@temperature_m)
    end

    if unit == 'fahrenheit' && (unit_m == 'celsius' || unit_m.to_s.empty?)
      @temperature_m = Converter.new.ctof(@temperature_m)
    end
  end
end
